package com.fs.store.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.store.domain.FsShippingTemplatesFree;
import com.fs.store.service.IFsShippingTemplatesFreeService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 免邮费Controller
 * 
 * @author fs
 * @date 2022-03-15
 */
@RestController
@RequestMapping("/store/shippingTemplatesFree")
public class FsShippingTemplatesFreeController extends BaseController
{
    @Autowired
    private IFsShippingTemplatesFreeService fsShippingTemplatesFreeService;

    /**
     * 查询免邮费列表
     */
    @PreAuthorize("@ss.hasPermi('store:shippingTemplatesFree:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsShippingTemplatesFree fsShippingTemplatesFree)
    {
        startPage();
        List<FsShippingTemplatesFree> list = fsShippingTemplatesFreeService.selectFsShippingTemplatesFreeList(fsShippingTemplatesFree);
        return getDataTable(list);
    }

    /**
     * 导出免邮费列表
     */
    @PreAuthorize("@ss.hasPermi('store:shippingTemplatesFree:export')")
    @Log(title = "免邮费", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsShippingTemplatesFree fsShippingTemplatesFree)
    {
        List<FsShippingTemplatesFree> list = fsShippingTemplatesFreeService.selectFsShippingTemplatesFreeList(fsShippingTemplatesFree);
        ExcelUtil<FsShippingTemplatesFree> util = new ExcelUtil<FsShippingTemplatesFree>(FsShippingTemplatesFree.class);
        return util.exportExcel(list, "shippingTemplatesFree");
    }

    /**
     * 获取免邮费详细信息
     */
    @PreAuthorize("@ss.hasPermi('store:shippingTemplatesFree:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(fsShippingTemplatesFreeService.selectFsShippingTemplatesFreeById(id));
    }

    /**
     * 新增免邮费
     */
    @PreAuthorize("@ss.hasPermi('store:shippingTemplatesFree:add')")
    @Log(title = "免邮费", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsShippingTemplatesFree fsShippingTemplatesFree)
    {
        return toAjax(fsShippingTemplatesFreeService.insertFsShippingTemplatesFree(fsShippingTemplatesFree));
    }

    /**
     * 修改免邮费
     */
    @PreAuthorize("@ss.hasPermi('store:shippingTemplatesFree:edit')")
    @Log(title = "免邮费", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsShippingTemplatesFree fsShippingTemplatesFree)
    {
        return toAjax(fsShippingTemplatesFreeService.updateFsShippingTemplatesFree(fsShippingTemplatesFree));
    }

    /**
     * 删除免邮费
     */
    @PreAuthorize("@ss.hasPermi('store:shippingTemplatesFree:remove')")
    @Log(title = "免邮费", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fsShippingTemplatesFreeService.deleteFsShippingTemplatesFreeByIds(ids));
    }
}
