package com.fs.store.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.store.domain.FsStoreCart;
import com.fs.store.service.IFsStoreCartService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 购物车Controller
 * 
 * @author fs
 * @date 2022-03-21
 */
@RestController
@RequestMapping("/store/storeCart")
public class FsStoreCartController extends BaseController
{
    @Autowired
    private IFsStoreCartService fsStoreCartService;

    /**
     * 查询购物车列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeCart:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreCart fsStoreCart)
    {
        startPage();
        List<FsStoreCart> list = fsStoreCartService.selectFsStoreCartList(fsStoreCart);
        return getDataTable(list);
    }

    /**
     * 导出购物车列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeCart:export')")
    @Log(title = "购物车", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsStoreCart fsStoreCart)
    {
        List<FsStoreCart> list = fsStoreCartService.selectFsStoreCartList(fsStoreCart);
        ExcelUtil<FsStoreCart> util = new ExcelUtil<FsStoreCart>(FsStoreCart.class);
        return util.exportExcel(list, "storeCart");
    }

    /**
     * 获取购物车详细信息
     */
    @PreAuthorize("@ss.hasPermi('store:storeCart:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(fsStoreCartService.selectFsStoreCartById(id));
    }

    /**
     * 新增购物车
     */
    @PreAuthorize("@ss.hasPermi('store:storeCart:add')")
    @Log(title = "购物车", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsStoreCart fsStoreCart)
    {
        return toAjax(fsStoreCartService.insertFsStoreCart(fsStoreCart));
    }

    /**
     * 修改购物车
     */
    @PreAuthorize("@ss.hasPermi('store:storeCart:edit')")
    @Log(title = "购物车", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsStoreCart fsStoreCart)
    {
        return toAjax(fsStoreCartService.updateFsStoreCart(fsStoreCart));
    }

    /**
     * 删除购物车
     */
    @PreAuthorize("@ss.hasPermi('store:storeCart:remove')")
    @Log(title = "购物车", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fsStoreCartService.deleteFsStoreCartByIds(ids));
    }
}
