package com.fs.store.controller;

import java.util.List;

import com.fs.common.utils.ParseUtils;
import com.fs.store.vo.FsStoreCouponUserVO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.store.domain.FsStoreCouponUser;
import com.fs.store.service.IFsStoreCouponUserService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 优惠券发放记录Controller
 *
 * @author fs
 * @date 2022-03-15
 */
@RestController
@RequestMapping("/store/storeCouponUser")
public class FsStoreCouponUserController extends BaseController
{
    @Autowired
    private IFsStoreCouponUserService fsStoreCouponUserService;

    /**
     * 查询优惠券发放记录列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreCouponUser fsStoreCouponUser)
    {
        startPage();
        List<FsStoreCouponUserVO> list = fsStoreCouponUserService.selectFsStoreCouponUserListVO(fsStoreCouponUser);
        for (FsStoreCouponUserVO  vo : list){
            vo.setPhone(ParseUtils.parsePhone(vo.getPhone()));
        }
        return getDataTable(list);
    }

    /**
     * 导出优惠券发放记录列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponUser:export')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsStoreCouponUser fsStoreCouponUser)
    {
        List<FsStoreCouponUserVO> list = fsStoreCouponUserService.selectFsStoreCouponUserListVO(fsStoreCouponUser);
        ExcelUtil<FsStoreCouponUserVO> util = new ExcelUtil<FsStoreCouponUserVO>(FsStoreCouponUserVO.class);
        return util.exportExcel(list, "优惠券领取记录");
    }

    /**
     * 获取优惠券发放记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponUser:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(fsStoreCouponUserService.selectFsStoreCouponUserById(id));
    }

    /**
     * 新增优惠券发放记录
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponUser:add')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsStoreCouponUser fsStoreCouponUser)
    {
        return toAjax(fsStoreCouponUserService.insertFsStoreCouponUser(fsStoreCouponUser));
    }

    /**
     * 修改优惠券发放记录
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponUser:edit')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsStoreCouponUser fsStoreCouponUser)
    {
        return toAjax(fsStoreCouponUserService.updateFsStoreCouponUser(fsStoreCouponUser));
    }

    /**
     * 删除优惠券发放记录
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponUser:remove')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fsStoreCouponUserService.deleteFsStoreCouponUserByIds(ids));
    }
}
