package com.fs.store.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.store.domain.FsStoreOrderStatus;
import com.fs.store.service.IFsStoreOrderStatusService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 订单操作记录Controller
 * 
 * @author fs
 * @date 2022-03-15
 */
@RestController
@RequestMapping("/store/storeOrderStatus")
public class FsStoreOrderStatusController extends BaseController
{
    @Autowired
    private IFsStoreOrderStatusService fsStoreOrderStatusService;

    /**
     * 查询订单操作记录列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeOrderStatus:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreOrderStatus fsStoreOrderStatus)
    {
        startPage();
        List<FsStoreOrderStatus> list = fsStoreOrderStatusService.selectFsStoreOrderStatusList(fsStoreOrderStatus);
        return getDataTable(list);
    }

    /**
     * 导出订单操作记录列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeOrderStatus:export')")
    @Log(title = "订单操作记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsStoreOrderStatus fsStoreOrderStatus)
    {
        List<FsStoreOrderStatus> list = fsStoreOrderStatusService.selectFsStoreOrderStatusList(fsStoreOrderStatus);
        ExcelUtil<FsStoreOrderStatus> util = new ExcelUtil<FsStoreOrderStatus>(FsStoreOrderStatus.class);
        return util.exportExcel(list, "storeOrderStatus");
    }

    /**
     * 获取订单操作记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('store:storeOrderStatus:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(fsStoreOrderStatusService.selectFsStoreOrderStatusById(id));
    }

    /**
     * 新增订单操作记录
     */
    @PreAuthorize("@ss.hasPermi('store:storeOrderStatus:add')")
    @Log(title = "订单操作记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsStoreOrderStatus fsStoreOrderStatus)
    {
        return toAjax(fsStoreOrderStatusService.insertFsStoreOrderStatus(fsStoreOrderStatus));
    }

    /**
     * 修改订单操作记录
     */
    @PreAuthorize("@ss.hasPermi('store:storeOrderStatus:edit')")
    @Log(title = "订单操作记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsStoreOrderStatus fsStoreOrderStatus)
    {
        return toAjax(fsStoreOrderStatusService.updateFsStoreOrderStatus(fsStoreOrderStatus));
    }

    /**
     * 删除订单操作记录
     */
    @PreAuthorize("@ss.hasPermi('store:storeOrderStatus:remove')")
    @Log(title = "订单操作记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fsStoreOrderStatusService.deleteFsStoreOrderStatusByIds(ids));
    }
}
