package com.fs.store.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.store.domain.FsUserRecharge;
import com.fs.store.service.IFsUserRechargeService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 用户充值Controller
 * 
 * @author fs
 * @date 2022-03-15
 */
@RestController
@RequestMapping("/store/userRecharge")
public class FsUserRechargeController extends BaseController
{
    @Autowired
    private IFsUserRechargeService fsUserRechargeService;

    /**
     * 查询用户充值列表
     */
    @PreAuthorize("@ss.hasPermi('store:userRecharge:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsUserRecharge fsUserRecharge)
    {
        startPage();
        List<FsUserRecharge> list = fsUserRechargeService.selectFsUserRechargeList(fsUserRecharge);
        return getDataTable(list);
    }

    /**
     * 导出用户充值列表
     */
    @PreAuthorize("@ss.hasPermi('store:userRecharge:export')")
    @Log(title = "用户充值", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsUserRecharge fsUserRecharge)
    {
        List<FsUserRecharge> list = fsUserRechargeService.selectFsUserRechargeList(fsUserRecharge);
        ExcelUtil<FsUserRecharge> util = new ExcelUtil<FsUserRecharge>(FsUserRecharge.class);
        return util.exportExcel(list, "userRecharge");
    }

    /**
     * 获取用户充值详细信息
     */
    @PreAuthorize("@ss.hasPermi('store:userRecharge:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(fsUserRechargeService.selectFsUserRechargeById(id));
    }

    /**
     * 新增用户充值
     */
    @PreAuthorize("@ss.hasPermi('store:userRecharge:add')")
    @Log(title = "用户充值", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsUserRecharge fsUserRecharge)
    {
        return toAjax(fsUserRechargeService.insertFsUserRecharge(fsUserRecharge));
    }

    /**
     * 修改用户充值
     */
    @PreAuthorize("@ss.hasPermi('store:userRecharge:edit')")
    @Log(title = "用户充值", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsUserRecharge fsUserRecharge)
    {
        return toAjax(fsUserRechargeService.updateFsUserRecharge(fsUserRecharge));
    }

    /**
     * 删除用户充值
     */
    @PreAuthorize("@ss.hasPermi('store:userRecharge:remove')")
    @Log(title = "用户充值", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fsUserRechargeService.deleteFsUserRechargeByIds(ids));
    }
}
