package com.fs.company.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;


import com.fs.common.core.redis.RedisCache;
import com.fs.company.domain.CompanyMenu;
import com.fs.company.domain.CompanyUser;
import com.fs.company.param.LoginToken;
import com.fs.company.service.ICompanyMenuService;
import com.fs.core.security.LoginBody;
import com.fs.core.security.LoginUser;
import com.fs.core.web.service.CompanyLoginService;
import com.fs.core.web.service.CompanyPermissionService;
import com.fs.core.web.service.TokenService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.constant.Constants;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.utils.ServletUtils;

/**
 * 登录验证
 *

 */
@RestController
public class CompanyLoginController
{
    @Autowired
    private CompanyLoginService loginService;

    @Autowired
    private ICompanyMenuService menuService;

    @Autowired
    private CompanyPermissionService permissionService;

    @Autowired
    private TokenService tokenService;
    @Autowired
    private RedisCache redisCache;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }

//    @PostMapping("/loginByToken")
//    public AjaxResult loginByAdmin(@RequestBody LoginToken param)
//    {
//        Long userId=redisCache.getCacheObject("")
//
//        AjaxResult ajax = AjaxResult.success();
//        // 生成令牌
//        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
//                loginBody.getUuid());
//        ajax.put(Constants.TOKEN, token);
//        return ajax;
//    }

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public AjaxResult getInfo()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        CompanyUser user = loginUser.getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        AjaxResult ajax = AjaxResult.success();
        ajax.put("user", user);
        ajax.put("roles", roles);
        ajax.put("permissions", permissions);


        return ajax;
    }

    /**
     * 获取路由信息
     *
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public AjaxResult getRouters()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        Long companyId =  loginUser.getCompany().getCompanyId();
        // 用户信息
        CompanyUser user = loginUser.getUser();
        List<CompanyMenu> menus = new ArrayList<>();
        if (companyId.equals(174L)){
            menus = menuService.selectMenuTreeByCompany(user.getUserId(), loginUser.getUser().isAdmin());
        }else {
            menus = menuService.selectMenuTreeByUserId(user.getUserId(), loginUser.getUser().isAdmin());
        }
        return AjaxResult.success(menuService.buildMenus(menus));
    }

}

