package com.fs.company.controller;

import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.domain.R;
import com.fs.common.core.page.TableDataInfo;
import com.fs.common.enums.BusinessType;
import com.fs.common.utils.ServletUtils;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.company.domain.CompanySmsTemp;
import com.fs.company.param.CompanySmsTempListQueryParam;
import com.fs.company.service.ICompanySmsTempService;
import com.fs.company.vo.CompanySmsTempListQueryVO;
import com.fs.company.vo.CompanySmsTempListVO;
import com.fs.core.security.LoginUser;
import com.fs.core.web.service.TokenService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 短信模板Controller
 * 
 * @author fs
 * @date 2023-01-09
 */
@RestController
@RequestMapping("/company/companySmsTemp")
public class CompanySmsTempController extends BaseController
{
    @Autowired
    private ICompanySmsTempService companySmsTempService;
    @Autowired
    private TokenService tokenService;
    /**
     * 查询短信模板列表
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:list')")
    @GetMapping("/list")
    public TableDataInfo list(CompanySmsTempListQueryParam companySmsTemp)
    {
        startPage();
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        companySmsTemp.setCompanyId(loginUser.getCompany().getCompanyId());
        List<CompanySmsTempListQueryVO> list = companySmsTempService.selectCompanySmsTempListQuery(companySmsTemp);
        return getDataTable(list);
    }

    /**
     * 导出短信模板列表
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:export')")
    @Log(title = "短信模板", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CompanySmsTempListQueryParam companySmsTemp)
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        companySmsTemp.setCompanyId(loginUser.getCompany().getCompanyId());
        List<CompanySmsTempListQueryVO> list = companySmsTempService.selectCompanySmsTempListQuery(companySmsTemp);
        ExcelUtil<CompanySmsTempListQueryVO> util = new ExcelUtil<CompanySmsTempListQueryVO>(CompanySmsTempListQueryVO.class);
        return util.exportExcel(list, "companySmsTemp");
    }

    /**
     * 获取短信模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:query')")
    @GetMapping(value = "/{tempId}")
    public AjaxResult getInfo(@PathVariable("tempId") Long tempId)
    {
        return AjaxResult.success(companySmsTempService.selectCompanySmsTempById(tempId));
    }

    /**
     * 新增短信模板
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:add')")
    @Log(title = "短信模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CompanySmsTemp companySmsTemp)
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        companySmsTemp.setStatus(0);
        companySmsTemp.setIsAudit(0);
        companySmsTemp.setCompanyId(loginUser.getCompany().getCompanyId());
        return toAjax(companySmsTempService.insertCompanySmsTemp(companySmsTemp));
    }

    /**
     * 修改短信模板
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:edit')")
    @Log(title = "短信模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CompanySmsTemp companySmsTemp)
    {
        return toAjax(companySmsTempService.updateCompanySmsTemp(companySmsTemp));
    }

    /**
     * 删除短信模板
     */
    @PreAuthorize("@ss.hasPermi('company:companySmsTemp:remove')")
    @Log(title = "短信模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{tempIds}")
    public AjaxResult remove(@PathVariable Long[] tempIds)
    {
        return toAjax(companySmsTempService.deleteCompanySmsTempByIds(tempIds));
    }


    @GetMapping("/getSmsTempList")
    public R getSmsTempList()
    {
        CompanySmsTempListQueryParam maps=new CompanySmsTempListQueryParam();
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        maps.setCompanyId(loginUser.getCompany().getCompanyId());
        maps.setStatus(1);
        maps.setIsAudit(1);
        List<CompanySmsTempListQueryVO> list = companySmsTempService.selectCompanySmsTempListQuery(maps);
        return R.ok().put("data",list);
    }
}
