package com.fs.doc.service;

import java.util.List;
import com.fs.doc.domain.DocOrderReply;
import com.fs.doc.param.DocOrderReplyQueryParam;
import com.fs.doc.vo.DocOrderReplyListQueryVO;

/**
 * 订单回复Service接口
 * 
 * @author fs
 * @date 2023-01-09
 */
public interface IDocOrderReplyService 
{
    /**
     * 查询订单回复
     * 
     * @param replyId 订单回复ID
     * @return 订单回复
     */
    public DocOrderReply selectDocOrderReplyById(Long replyId);

    /**
     * 查询订单回复列表
     * 
     * @param docOrderReply 订单回复
     * @return 订单回复集合
     */
    public List<DocOrderReply> selectDocOrderReplyList(DocOrderReply docOrderReply);

    /**
     * 新增订单回复
     * 
     * @param docOrderReply 订单回复
     * @return 结果
     */
    public int insertDocOrderReply(DocOrderReply docOrderReply);

    /**
     * 修改订单回复
     * 
     * @param docOrderReply 订单回复
     * @return 结果
     */
    public int updateDocOrderReply(DocOrderReply docOrderReply);

    /**
     * 批量删除订单回复
     * 
     * @param replyIds 需要删除的订单回复ID
     * @return 结果
     */
    public int deleteDocOrderReplyByIds(Long[] replyIds);

    /**
     * 删除订单回复信息
     * 
     * @param replyId 订单回复ID
     * @return 结果
     */
    public int deleteDocOrderReplyById(Long replyId);

    List<DocOrderReplyListQueryVO> selectDocOrderReplyListVOQuery(DocOrderReplyQueryParam param);
}
