package com.fs.doc.service;

import java.util.List;
import com.fs.doc.domain.DocRecord;
import com.fs.doc.param.DocRecordParam;
import com.fs.doc.param.DocRecordQueryParam;
import com.fs.doc.vo.DocRecordListQueryVO;
import com.fs.doc.vo.DocRecordVO;

/**
 * 记录Service接口
 * 
 * @author fs
 * @date 2023-01-09
 */
public interface IDocRecordService 
{
    /**
     * 查询记录
     * 
     * @param recordId 记录ID
     * @return 记录
     */
    public DocRecord selectDocRecordById(Long recordId);

    /**
     * 查询记录列表
     * 
     * @param docRecord 记录
     * @return 记录集合
     */
    public List<DocRecord> selectDocRecordList(DocRecord docRecord);

    /**
     * 新增记录
     * 
     * @param docRecord 记录
     * @return 结果
     */
    public int insertDocRecord(DocRecord docRecord);

    /**
     * 修改记录
     * 
     * @param docRecord 记录
     * @return 结果
     */
    public int updateDocRecord(DocRecord docRecord);

    /**
     * 批量删除记录
     * 
     * @param recordIds 需要删除的记录ID
     * @return 结果
     */
    public int deleteDocRecordByIds(Long[] recordIds);

    /**
     * 删除记录信息
     * 
     * @param recordId 记录ID
     * @return 结果
     */
    public int deleteDocRecordById(Long recordId);

    List<DocRecordListQueryVO> selectDocRecordListVOQuery(DocRecordQueryParam param);

    List<DocRecordVO> selectDocRecordListVO(DocRecordParam docRecord);
}
