package com.fs.doc.service;

import java.util.List;
import com.fs.doc.domain.Doc;
import com.fs.doc.param.DocQueryParam;
import com.fs.doc.vo.DocListQueryVO;

/**
 * 档案Service接口
 * 
 * @author fs
 * @date 2023-01-09
 */
public interface IDocService 
{
    /**
     * 查询档案
     * 
     * @param docId 档案ID
     * @return 档案
     */
    public Doc selectDocById(Long docId);

    /**
     * 查询档案列表
     * 
     * @param doc 档案
     * @return 档案集合
     */
    public List<Doc> selectDocList(Doc doc);

    /**
     * 新增档案
     * 
     * @param doc 档案
     * @return 结果
     */
    public int insertDoc(Doc doc);

    /**
     * 修改档案
     * 
     * @param doc 档案
     * @return 结果
     */
    public int updateDoc(Doc doc);

    /**
     * 批量删除档案
     * 
     * @param docIds 需要删除的档案ID
     * @return 结果
     */
    public int deleteDocByIds(Long[] docIds);

    /**
     * 删除档案信息
     * 
     * @param docId 档案ID
     * @return 结果
     */
    public int deleteDocById(Long docId);

    List<DocListQueryVO> selectDocListVOQuery(DocQueryParam param);
}
