package com.fs.huifuPay.dto;

import lombok.Data;
import java.io.Serializable;

/**
 * 响应结果DTO
 *
 * <p>
 *     此类用于封装服务响应结果。
 *     包含返回类型、返回码、返回消息、令牌以及随机安全码等信息。
 * </p>
 *
 * @author xdd
 * @since 2025-02-27
 */
@Data
public class ReqTokenResultDTO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 返回类型
     * <p>
     *     示例值: "S"
     *     通常表示成功或失败，"S" 可能代表 Success。
     * </p>
     */
    private String retType;

    /**
     * 返回码
     * <p>
     *     示例值: "00000000"
     *     通常 "00000000" 或类似的编码表示成功。
     * </p>
     */
    private String retCode;

    /**
     * 返回消息
     * <p>
     *     示例值: "success"
     *     对返回码的文字描述。
     * </p>
     */
    private String retMsg;

    /**
     * 令牌
     * <p>
     *     示例值: "94383736-6870-4bed-8bda-4a23977c9d90"
     *     用于后续请求的身份验证或授权。
     * </p>
     */
    private String token;

    /**
     * 随机安全码
     * <p>
     *     示例值: "68954728665455B127D943947B6BACF1"
     *     用于增强安全性，例如防止重放攻击。
     * </p>
     */
    private String randomSec;
}
