package com.fs.oms.service;

import java.util.List;
import com.fs.oms.domain.OmsOrder;
import com.fs.oms.param.OmsInnerOrderParam;
import com.fs.oms.vo.OmsInnerOrderVO;
import org.apache.ibatis.annotations.Param;

/**
 * oms销售订单Service接口
 *
 * @author fs
 * @date 2023-06-26
 */
public interface IOmsOrderService
{
    /**
     * 查询oms销售订单
     *
     * @param id oms销售订单ID
     * @return oms销售订单
     */
    public OmsOrder selectOmsOrderById(Long id);

    /**
     * 查询oms销售订单列表
     *
     * @param omsOrder oms销售订单
     * @return oms销售订单集合
     */
    public List<OmsOrder> selectOmsOrderList(OmsOrder omsOrder);

    /**
     * 新增oms销售订单
     *
     * @param omsOrder oms销售订单
     * @return 结果
     */
    public int insertOmsOrder(OmsOrder omsOrder);

    /**
     * 修改oms销售订单
     *
     * @param omsOrder oms销售订单
     * @return 结果
     */
    public int updateOmsOrder(OmsOrder omsOrder);

    /**
     * 批量删除oms销售订单
     *
     * @param ids 需要删除的oms销售订单ID
     * @return 结果
     */
    public int deleteOmsOrderByIds(Long[] ids);

    /**
     * 删除oms销售订单信息
     *
     * @param id oms销售订单ID
     * @return 结果
     */
    public int deleteOmsOrderById(Long id);

    /**
     * 查询oms内部销售订单列表
     *
     * @param omsOrder oms内部销售订单
     * @return oms内部销售订单集合
     */
    public List<OmsInnerOrderVO> selectOmsInnerOrderListVO(OmsInnerOrderParam omsOrder);
}
