package com.fs.oms.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.oms.mapper.OmsLogisticsMapper;
import com.fs.oms.domain.OmsLogistics;
import com.fs.oms.service.IOmsLogisticsService;

/**
 * 物流管理Service业务层处理
 * 
 * @author oms
 * @date 2023-07-07
 */
@Service
public class OmsLogisticsServiceImpl implements IOmsLogisticsService 
{
    @Autowired
    private OmsLogisticsMapper omsLogisticsMapper;

    /**
     * 查询物流管理
     * 
     * @param id 物流管理ID
     * @return 物流管理
     */
    @Override
    public OmsLogistics selectOmsLogisticsById(Long id)
    {
        return omsLogisticsMapper.selectOmsLogisticsById(id);
    }

    /**
     * 查询物流管理列表
     * 
     * @param omsLogistics 物流管理
     * @return 物流管理
     */
    @Override
    public List<OmsLogistics> selectOmsLogisticsList(OmsLogistics omsLogistics)
    {
        return omsLogisticsMapper.selectOmsLogisticsList(omsLogistics);
    }

    /**
     * 新增物流管理
     * 
     * @param omsLogistics 物流管理
     * @return 结果
     */
    @Override
    public int insertOmsLogistics(OmsLogistics omsLogistics)
    {
        omsLogistics.setCreateTime(DateUtils.getNowDate());
        return omsLogisticsMapper.insertOmsLogistics(omsLogistics);
    }

    /**
     * 修改物流管理
     * 
     * @param omsLogistics 物流管理
     * @return 结果
     */
    @Override
    public int updateOmsLogistics(OmsLogistics omsLogistics)
    {
        omsLogistics.setUpdateTime(DateUtils.getNowDate());
        return omsLogisticsMapper.updateOmsLogistics(omsLogistics);
    }

    /**
     * 批量删除物流管理
     * 
     * @param ids 需要删除的物流管理ID
     * @return 结果
     */
    @Override
    public int deleteOmsLogisticsByIds(Long[] ids)
    {
        return omsLogisticsMapper.deleteOmsLogisticsByIds(ids);
    }

    /**
     * 删除物流管理信息
     * 
     * @param id 物流管理ID
     * @return 结果
     */
    @Override
    public int deleteOmsLogisticsById(Long id)
    {
        return omsLogisticsMapper.deleteOmsLogisticsById(id);
    }
}
