package com.fs.oms.service.impl;

import java.util.List;

import com.fs.oms.mapper.OmsProductAttrMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.oms.domain.OmsProductAttr;
import com.fs.oms.service.IOmsProductAttrService;

/**
 * 商品属性Service业务层处理
 * 
 * @author fs
 * @date 2023-06-07
 */
@Service
public class OmsProductAttrServiceImpl implements IOmsProductAttrService 
{
    @Autowired
    private OmsProductAttrMapper omsProductAttrMapper;

    /**
     * 查询商品属性
     * 
     * @param id 商品属性ID
     * @return 商品属性
     */
    @Override
    public OmsProductAttr selectOmsProductAttrById(Long id)
    {
        return omsProductAttrMapper.selectOmsProductAttrById(id);
    }

    /**
     * 查询商品属性列表
     * 
     * @param omsProductAttr 商品属性
     * @return 商品属性
     */
    @Override
    public List<OmsProductAttr> selectOmsProductAttrList(OmsProductAttr omsProductAttr)
    {
        return omsProductAttrMapper.selectOmsProductAttrList(omsProductAttr);
    }

    /**
     * 新增商品属性
     * 
     * @param omsProductAttr 商品属性
     * @return 结果
     */
    @Override
    public int insertOmsProductAttr(OmsProductAttr omsProductAttr)
    {
        return omsProductAttrMapper.insertOmsProductAttr(omsProductAttr);
    }

    /**
     * 修改商品属性
     * 
     * @param omsProductAttr 商品属性
     * @return 结果
     */
    @Override
    public int updateOmsProductAttr(OmsProductAttr omsProductAttr)
    {
        return omsProductAttrMapper.updateOmsProductAttr(omsProductAttr);
    }

    /**
     * 批量删除商品属性
     * 
     * @param ids 需要删除的商品属性ID
     * @return 结果
     */
    @Override
    public int deleteOmsProductAttrByIds(Long[] ids)
    {
        return omsProductAttrMapper.deleteOmsProductAttrByIds(ids);
    }

    /**
     * 删除商品属性信息
     * 
     * @param id 商品属性ID
     * @return 结果
     */
    @Override
    public int deleteOmsProductAttrById(Long id)
    {
        return omsProductAttrMapper.deleteOmsProductAttrById(id);
    }

    @Override
    public List<OmsProductAttr> selectOmsProductAttrByProductId(Long productId) {
        return omsProductAttrMapper.selectOmsProductAttrByProductId(productId);
    }
}
