package com.fs.oms.service.impl;

import java.util.List;

import com.fs.oms.param.OmsProductAttrValueParam;
import com.fs.oms.vo.OmsProductAttrValueVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.oms.mapper.OmsProductAttrValueMapper;
import com.fs.oms.domain.OmsProductAttrValue;
import com.fs.oms.service.IOmsProductAttrValueService;

/**
 * 商品属性值Service业务层处理
 * 
 * @author fs
 * @date 2023-06-07
 */
@Service
public class OmsProductAttrValueServiceImpl implements IOmsProductAttrValueService 
{
    @Autowired
    private OmsProductAttrValueMapper omsProductAttrValueMapper;

    /**
     * 查询商品属性值
     * 
     * @param id 商品属性值ID
     * @return 商品属性值
     */
    @Override
    public OmsProductAttrValue selectOmsProductAttrValueById(Long id)
    {
        return omsProductAttrValueMapper.selectOmsProductAttrValueById(id);
    }

    /**
     * 查询商品属性值列表
     * 
     * @param omsProductAttrValue 商品属性值
     * @return 商品属性值
     */
    @Override
    public List<OmsProductAttrValue> selectOmsProductAttrValueList(OmsProductAttrValue omsProductAttrValue)
    {
        return omsProductAttrValueMapper.selectOmsProductAttrValueList(omsProductAttrValue);
    }

    /**
     * 新增商品属性值
     * 
     * @param omsProductAttrValue 商品属性值
     * @return 结果
     */
    @Override
    public int insertOmsProductAttrValue(OmsProductAttrValue omsProductAttrValue)
    {
        return omsProductAttrValueMapper.insertOmsProductAttrValue(omsProductAttrValue);
    }

    /**
     * 修改商品属性值
     * 
     * @param omsProductAttrValue 商品属性值
     * @return 结果
     */
    @Override
    public int updateOmsProductAttrValue(OmsProductAttrValue omsProductAttrValue)
    {
        return omsProductAttrValueMapper.updateOmsProductAttrValue(omsProductAttrValue);
    }

    /**
     * 批量删除商品属性值
     * 
     * @param ids 需要删除的商品属性值ID
     * @return 结果
     */
    @Override
    public int deleteOmsProductAttrValueByIds(Long[] ids)
    {
        return omsProductAttrValueMapper.deleteOmsProductAttrValueByIds(ids);
    }

    /**
     * 删除商品属性值信息
     * 
     * @param id 商品属性值ID
     * @return 结果
     */
    @Override
    public int deleteOmsProductAttrValueById(Long id)
    {
        return omsProductAttrValueMapper.deleteOmsProductAttrValueById(id);
    }

    @Override
    public List<OmsProductAttrValueVO> selectOmsProductAttrValueListVO(OmsProductAttrValueParam param) {
        return omsProductAttrValueMapper.selectOmsProductAttrValueListVO(param);
    }
}
