package com.fs.oms.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.oms.mapper.OmsProductCategoryMapper;
import com.fs.oms.domain.OmsProductCategory;
import com.fs.oms.service.IOmsProductCategoryService;

/**
 * 商品分类Service业务层处理
 * 
 * @author fs
 * @date 2023-06-09
 */
@Service
public class OmsProductCategoryServiceImpl implements IOmsProductCategoryService 
{
    @Autowired
    private OmsProductCategoryMapper omsProductCategoryMapper;

    /**
     * 查询商品分类
     * 
     * @param cateId 商品分类ID
     * @return 商品分类
     */
    @Override
    public OmsProductCategory selectOmsProductCategoryById(Long cateId)
    {
        return omsProductCategoryMapper.selectOmsProductCategoryById(cateId);
    }

    /**
     * 查询商品分类列表
     * 
     * @param omsProductCategory 商品分类
     * @return 商品分类
     */
    @Override
    public List<OmsProductCategory> selectOmsProductCategoryList(OmsProductCategory omsProductCategory)
    {
        return omsProductCategoryMapper.selectOmsProductCategoryList(omsProductCategory);
    }

    /**
     * 新增商品分类
     * 
     * @param omsProductCategory 商品分类
     * @return 结果
     */
    @Override
    public int insertOmsProductCategory(OmsProductCategory omsProductCategory)
    {
        omsProductCategory.setCreateTime(DateUtils.getNowDate());
        return omsProductCategoryMapper.insertOmsProductCategory(omsProductCategory);
    }

    /**
     * 修改商品分类
     * 
     * @param omsProductCategory 商品分类
     * @return 结果
     */
    @Override
    public int updateOmsProductCategory(OmsProductCategory omsProductCategory)
    {
        omsProductCategory.setUpdateTime(DateUtils.getNowDate());
        return omsProductCategoryMapper.updateOmsProductCategory(omsProductCategory);
    }

    /**
     * 批量删除商品分类
     * 
     * @param cateIds 需要删除的商品分类ID
     * @return 结果
     */
    @Override
    public int deleteOmsProductCategoryByIds(Long[] cateIds)
    {
        return omsProductCategoryMapper.deleteOmsProductCategoryByIds(cateIds);
    }

    /**
     * 删除商品分类信息
     * 
     * @param cateId 商品分类ID
     * @return 结果
     */
    @Override
    public int deleteOmsProductCategoryById(Long cateId)
    {
        return omsProductCategoryMapper.deleteOmsProductCategoryById(cateId);
    }
}
