package com.fs.qw.mapper;


import com.fs.qw.domain.QwLabel;
import com.fs.qw.domain.QwUser;
import com.fs.qw.vo.QwUserVO;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 企微功能账号管理Mapper接口
 *
 * @author fs
 * @date 2023-08-23
 */
public interface QwLabelMapper
{
    /**
     * 查询企微标签
     *
     * @param id 企微标签ID
     * @return 企微标签
     */
    public QwLabel selectQwLabelById(Long id);

    /**
     * 查询企微标签列表
     *
     * @param qwLabel 企微标签
     * @return 企微标签集合
     */
    public List<QwLabel> selectQwLabelList(QwLabel qwLabel);

    /**
     * 新增企微标签
     *
     * @param qwLabel 企微标签
     * @return 结果
     */
    public int insertQwLabel(QwLabel qwLabel);

    /**
     * 修改企微标签
     *
     * @param qwLabel 企微标签
     * @return 结果
     */
    public int updateQwLabel(QwLabel qwLabel);

    /**
     * 删除企微标签
     *
     * @param id 企微标签ID
     * @return 结果
     */
    public int deleteQwLabelById(Long id);

    /**
     * 批量删除企微标签
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteQwLabelByIds(Long[] ids);

    @Select("select label_id from qw_label where device_id =#{deviceId}")
    List<Long> selectLabelByDeviceId(String deviceId);

    @Select("select * from qw_label where label_id =#{labelId} and home_user_id =#{homeUserId}")
    QwLabel selectLabelByHomeUser(@Param("labelId") Long labelId,@Param("homeUserId") String homeUserId);
}
