package com.fs.qw.service;

import java.util.Date;
import java.util.List;
import com.fs.qw.domain.QwAccount;
import com.fs.qw.domain.QwAccountAudit;
import com.fs.qw.dto.QwOnlineStatusDTO;
import com.fs.qw.param.QwAccountParam;
import com.fs.qw.vo.QwAccountListVO;

/**
 * 企微功能账号管理Service接口
 *
 * @author fs
 * @date 2023-08-23
 */
public interface IQwAccountService
{
    /**
     * 查询企微功能账号管理
     *
     * @param id 企微功能账号管理ID
     * @return 企微功能账号管理
     */
    public QwAccount selectQwAccountById(Long id);

    /**
     * 查询企微功能账号管理列表
     *
     * @param qwAccount 企微功能账号管理
     * @return 企微功能账号管理集合
     */
    public List<QwAccount> selectQwAccountList(QwAccount qwAccount);

    /**
     * 新增企微功能账号管理
     *
     * @param qwAccount 企微功能账号管理
     * @return 结果
     */
    public int insertQwAccount(QwAccount qwAccount);

    /**
     * 修改企微功能账号管理
     *
     * @param qwAccount 企微功能账号管理
     * @return 结果
     */
    public int updateQwAccount(QwAccount qwAccount);

    /**
     * 批量删除企微功能账号管理
     *
     * @param ids 需要删除的企微功能账号管理ID
     * @return 结果
     */
    public int deleteQwAccountByIds(Long[] ids);

    /**
     * 删除企微功能账号管理信息
     *
     * @param id 企微功能账号管理ID
     * @return 结果
     */
    public int deleteQwAccountById(Long id);


    List<QwAccountListVO> selectQwAccounts(QwAccountParam param);

    List<QwAccountListVO> selectAllQwAccounts(QwAccountParam param);

    int updateDevice(QwAccount qwAccount);

    int auditQwAccount(QwAccountAudit audit);

    String getDeviceIdByAccount(String account);

    int selectAccountCount(String account);

    void updateAuthCheckByDeviceId(QwOnlineStatusDTO qwOnlineStatusDTO);


}
