package com.fs.qw.service;


import com.fs.common.core.domain.R;
import com.fs.qw.domain.QwMessage;
import com.fs.qw.domain.QwMessageImage;
import com.fs.qw.domain.QwMessageListParam;
import com.fs.qw.dto.QwMessageDTO;
import com.fs.qw.event.EventQwMessage;
import com.fs.qw.domain.QwMessageText;
import com.fs.qw.vo.QwMessageListExportVO;
import com.fs.qw.vo.QwMessageListVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 企微功能账号管理Service接口
 *
 * @author fs
 * @date 2023-08-23
 */
public interface IQwMessageService
{
    /**
     * 查询企微消息
     *
     * @param id 企微消息ID
     * @return 企微消息
     */
    public QwMessage selectQwMessageById(Long id);

    /**
     * 查询企微消息列表
     *
     * @param qwMessage 企微消息
     * @return 企微消息集合
     */
    public List<QwMessage> selectQwMessageList(QwMessage qwMessage);

    /**
     * 新增企微消息
     *
     * @param qwMessage 企微消息
     * @return 结果
     */
    public void insertQwMessage(QwMessage qwMessage);

    /**
     * 修改企微消息
     *
     * @param qwMessage 企微消息
     * @return 结果
     */
    public int updateQwMessage(QwMessage qwMessage);

    /**
     * 批量删除企微消息
     *
     * @param ids 需要删除的企微消息ID
     * @return 结果
     */
    public int deleteQwMessageByIds(Long[] ids);

    /**
     * 删除企微消息信息
     *
     * @param id 企微消息ID
     * @return 结果
     */
    public int deleteQwMessageById(Long id);

    R sendMessageText(QwMessageDTO qwMessageDTO);

    void sendWarningMessage(QwMessageText qwMessageText);

    R sendMessageImage(QwMessageDTO qwMessageDTO);

    R sendMessageVoice(QwMessageDTO qwMessageDTO);

    R messageRevoke(QwMessageDTO qwMessageDTO);

    List<QwMessageListVO> selectQwMessageListVO(String conversationId);


    List<QwMessage> selectQwMessageListByTypeVO(QwMessageListParam param);

    List<QwMessage> selectQwMessageListContextVO(QwMessageListParam param);

    List<QwMessageListVO> getQwMessageListVO(List<QwMessage> qwMessageList,String conversationId, int isRoom);

    List<QwMessageListExportVO> selectMessageListExportVO(String conversationId);


}
