package com.fs.qw.service.impl;

import java.util.Date;
import java.util.List;
import java.util.UUID;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwAccountAudit;
import com.fs.qw.dto.QwOnlineStatusDTO;
import com.fs.qw.param.QwAccountParam;
import com.fs.qw.vo.QwAccountListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.qw.mapper.QwAccountMapper;
import com.fs.qw.domain.QwAccount;
import com.fs.qw.service.IQwAccountService;

/**
 * 企微功能账号管理Service业务层处理
 *
 * @author fs
 * @date 2023-08-23
 */
@Service
public class QwAccountServiceImpl implements IQwAccountService
{
    @Autowired
    private QwAccountMapper qwAccountMapper;

    /**
     * 查询企微功能账号管理
     *
     * @param id 企微功能账号管理ID
     * @return 企微功能账号管理
     */
    @Override
    public QwAccount selectQwAccountById(Long id)
    {
        return qwAccountMapper.selectQwAccountById(id);
    }

    /**
     * 查询企微功能账号管理列表
     *
     * @param qwAccount 企微功能账号管理
     * @return 企微功能账号管理
     */
    @Override
    public List<QwAccount> selectQwAccountList(QwAccount qwAccount)
    {
        return qwAccountMapper.selectQwAccountList(qwAccount);
    }

    /**
     * 新增企微功能账号管理
     *
     * @param qwAccount 企微功能账号管理
     * @return 结果
     */
    @Override
    public int insertQwAccount(QwAccount qwAccount)
    {
        qwAccount.setCreateTime(DateUtils.getNowDate());
        qwAccount.setIsAudit(0L);
        qwAccount.setAvailableDevice(1L);
        return qwAccountMapper.insertQwAccount(qwAccount);
    }

    /**
     * 修改企微功能账号管理
     *
     * @param qwAccount 企微功能账号管理
     * @return 结果
     */
    @Override
    public int updateQwAccount(QwAccount qwAccount)
    {
        qwAccount.setUpdateTime(DateUtils.getNowDate());
        qwAccount.setIsAudit(0L);
        return qwAccountMapper.updateQwAccount(qwAccount);
    }

    /**
     * 批量删除企微功能账号管理
     *
     * @param ids 需要删除的企微功能账号管理ID
     * @return 结果
     */
    @Override
    public int deleteQwAccountByIds(Long[] ids)
    {
        return qwAccountMapper.deleteQwAccountByIds(ids);
    }

    /**
     * 删除企微功能账号管理信息
     *
     * @param id 企微功能账号管理ID
     * @return 结果
     */
    @Override
    public int deleteQwAccountById(Long id)
    {
        return qwAccountMapper.deleteQwAccountById(id);
    }

    @Override
    public List<QwAccountListVO> selectQwAccounts(QwAccountParam param) {
        return qwAccountMapper.selectQwAccounts(param);
    }

    @Override
    public List<QwAccountListVO> selectAllQwAccounts(QwAccountParam param) {
        return qwAccountMapper.selectAllQwAccounts(param);
    }

    @Override
    public int auditQwAccount(QwAccountAudit audit) {
        if (audit.getIsAudit()== 1){
            UUID uuid = UUID.randomUUID();
            String deviceId = uuid.toString().replaceAll("-", "");
            audit.setDeviceId(deviceId);
        }
        return qwAccountMapper.auditQwAccount(audit);
    }

    @Override
    public String getDeviceIdByAccount(String account) {
      return  qwAccountMapper.getDeviceIdByAccount(account);
    }

    @Override
    public int selectAccountCount(String account) {
        return qwAccountMapper.selectAccountCount(account);
    }

    @Override
    public int updateDevice(QwAccount qwAccount) {
            if (qwAccount.getAvailableDevice()==-1){
                qwAccount.setDeviceId(UUID.randomUUID().toString().replaceAll("-",""));
                qwAccount.setAvailableDevice(1L);
            }
        return qwAccountMapper.updateDevice(qwAccount);
    }

    @Override
    public void updateAuthCheckByDeviceId(QwOnlineStatusDTO qwOnlineStatusDTO) {
        if (qwOnlineStatusDTO.getAuthCheck()){
            qwAccountMapper.setAuthCheckByDeviceId(qwOnlineStatusDTO);
        }else {
            qwAccountMapper.setOfflineByDeviceId(qwOnlineStatusDTO);
        }

    }
}
