package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwLabel;
import com.fs.qw.domain.QwUser;
import com.fs.qw.mapper.QwLabelMapper;
import com.fs.qw.mapper.QwUserMapper;
import com.fs.qw.service.IQwLabelService;
import com.fs.qw.service.IQwUserService;
import com.fs.qw.vo.QwUserVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 企微功能账号管理Service业务层处理
 *
 * @author fs
 * @date 2023-08-23
 */
@Service
public class QwLabelServiceImpl implements IQwLabelService {
    @Autowired
    private QwLabelMapper qwLabelMapper;

    /**
     * 查询企微标签
     *
     * @param id 企微标签ID
     * @return 企微标签
     */
    @Override
    public QwLabel selectQwLabelById(Long id)
    {
        return qwLabelMapper.selectQwLabelById(id);
    }

    /**
     * 查询企微标签列表
     *
     * @param qwLabel 企微标签
     * @return 企微标签
     */
    @Override
    public List<QwLabel> selectQwLabelList(QwLabel qwLabel)
    {
        return qwLabelMapper.selectQwLabelList(qwLabel);
    }

    /**
     * 新增企微标签
     *
     * @param qwLabel 企微标签
     * @return 结果
     */
    @Override
    public int insertQwLabel(QwLabel qwLabel)
    {
        return qwLabelMapper.insertQwLabel(qwLabel);
    }

    /**
     * 修改企微标签
     *
     * @param qwLabel 企微标签
     * @return 结果
     */
    @Override
    public int updateQwLabel(QwLabel qwLabel)
    {
        return qwLabelMapper.updateQwLabel(qwLabel);
    }

    /**
     * 批量删除企微标签
     *
     * @param ids 需要删除的企微标签ID
     * @return 结果
     */
    @Override
    public int deleteQwLabelByIds(Long[] ids)
    {
        return qwLabelMapper.deleteQwLabelByIds(ids);
    }

    /**
     * 删除企微标签信息
     *
     * @param id 企微标签ID
     * @return 结果
     */
    @Override
    public int deleteQwLabelById(Long id)
    {
        return qwLabelMapper.deleteQwLabelById(id);
    }
}
