package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwMaterial;
import com.fs.qw.domain.QwMaterialGroup;
import com.fs.qw.mapper.QwMaterialGroupMapper;
import com.fs.qw.mapper.QwMaterialMapper;
import com.fs.qw.service.IQwMaterialGroupService;
import com.fs.qw.service.IQwMaterialService;
import com.fs.qw.utils.QwUploadUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@Service
public class QwMaterialGroupServiceImpl implements IQwMaterialGroupService
{
    @Autowired
    private QwMaterialGroupMapper qwMaterialGroupMapper;

    /**
     * 查询企微素材分组
     *
     * @param groupId 企微素材分组ID
     * @return 企微素材分组
     */
    @Override
    public QwMaterialGroup selectQwMaterialGroupById(Long groupId)
    {
        return qwMaterialGroupMapper.selectQwMaterialGroupById(groupId);
    }

    /**
     * 查询企微素材分组列表
     *
     * @param qwMaterialGroup 企微素材分组
     * @return 企微素材分组
     */
    @Override
    public List<QwMaterialGroup> selectQwMaterialGroupList(QwMaterialGroup qwMaterialGroup)
    {
        return qwMaterialGroupMapper.selectQwMaterialGroupList(qwMaterialGroup);
    }

    /**
     * 新增企微素材分组
     *
     * @param qwMaterialGroup 企微素材分组
     * @return 结果
     */
    @Override
    public int insertQwMaterialGroup(QwMaterialGroup qwMaterialGroup)
    {
        qwMaterialGroup.setCreateTime(DateUtils.getNowDate());
        return qwMaterialGroupMapper.insertQwMaterialGroup(qwMaterialGroup);
    }

    /**
     * 修改企微素材分组
     *
     * @param qwMaterialGroup 企微素材分组
     * @return 结果
     */
    @Override
    public int updateQwMaterialGroup(QwMaterialGroup qwMaterialGroup)
    {
        qwMaterialGroup.setUpdateTime(DateUtils.getNowDate());
        return qwMaterialGroupMapper.updateQwMaterialGroup(qwMaterialGroup);
    }

    /**
     * 批量删除企微素材分组
     *
     * @param groupIds 需要删除的企微素材分组ID
     * @return 结果
     */
    @Override
    public int deleteQwMaterialGroupByIds(Long[] groupIds)
    {
        return qwMaterialGroupMapper.deleteQwMaterialGroupByIds(groupIds);
    }

    /**
     * 删除企微素材分组信息
     *
     * @param groupId 企微素材分组ID
     * @return 结果
     */
    @Override
    public int deleteQwMaterialGroupById(Long groupId)
    {
        return qwMaterialGroupMapper.deleteQwMaterialGroupById(groupId);
    }
}
