package com.fs.qw.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qw.domain.QwAccount;
import com.fs.qw.domain.QwAccountAudit;
import com.fs.qw.domain.WeChatMessageGather;
import com.fs.qw.dto.QwOnlineStatusDTO;
import com.fs.qw.mapper.QwAccountMapper;
import com.fs.qw.mapper.WeChatMessageGatherMapper;
import com.fs.qw.param.QwAccountParam;
import com.fs.qw.service.IQwAccountService;
import com.fs.qw.service.IWeChatMessageGatherService;
import com.fs.qw.vo.QwAccountListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.UUID;

/**
 * 企微功能账号管理Service业务层处理
 *
 * @author fs
 * @date 2023-08-23
 */
@Service
public class WeChatMessageGatherServiceImpl implements IWeChatMessageGatherService
{
    @Autowired
    private WeChatMessageGatherMapper weChatMessageGatherMapper;

    /**
     * 查询企微会话存档
     *
     * @param id 企微会话存档ID
     * @return 企微会话存档
     */
    @Override
    public WeChatMessageGather selectWeChatMessageGatherById(Long id)
    {
        return weChatMessageGatherMapper.selectWeChatMessageGatherById(id);
    }

    /**
     * 查询企微会话存档列表
     *
     * @param weChatMessageGather 企微会话存档
     * @return 企微会话存档
     */
    @Override
    public List<WeChatMessageGather> selectWeChatMessageGatherList(WeChatMessageGather weChatMessageGather)
    {
        return weChatMessageGatherMapper.selectWeChatMessageGatherList(weChatMessageGather);
    }

    /**
     * 新增企微会话存档
     *
     * @param weChatMessageGather 企微会话存档
     * @return 结果
     */
    @Override
    public void insertWeChatMessageGather(WeChatMessageGather weChatMessageGather)
    {
        boolean isExists = weChatMessageGatherMapper.messageIsExist(weChatMessageGather.getMsgId());
        if (!isExists){
            weChatMessageGatherMapper.insertWeChatMessageGather(weChatMessageGather);
        }
    }

    /**
     * 修改企微会话存档
     *
     * @param weChatMessageGather 企微会话存档
     * @return 结果
     */
    @Override
    public int updateWeChatMessageGather(WeChatMessageGather weChatMessageGather)
    {
        return weChatMessageGatherMapper.updateWeChatMessageGather(weChatMessageGather);
    }

    /**
     * 批量删除企微会话存档
     *
     * @param ids 需要删除的企微会话存档ID
     * @return 结果
     */
    @Override
    public int deleteWeChatMessageGatherByIds(Long[] ids)
    {
        return weChatMessageGatherMapper.deleteWeChatMessageGatherByIds(ids);
    }

    /**
     * 删除企微会话存档信息
     *
     * @param id 企微会话存档ID
     * @return 结果
     */
    @Override
    public int deleteWeChatMessageGatherById(Long id)
    {
        return weChatMessageGatherMapper.deleteWeChatMessageGatherById(id);
    }
}
