package com.fs.qywx.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.qywx.domain.QywxApp;
import com.fs.qywx.domain.QywxCompany;
import com.fs.qywx.mapper.QywxAppMapper;
import com.fs.qywx.mapper.QywxCompanyMapper;
import com.fs.qywx.mapper.QywxUserMapper;
import com.fs.qywx.service.IQywxAppService;
import com.fs.qywx.service.IQywxCompanyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 企业微信三方应用授权公司Service业务层处理
 *
 * @author fs
 * @date 2023-07-24
 */
@Service
public class QywxAppServiceImpl implements IQywxAppService
{
    @Autowired
    private QywxAppMapper qywxAppMapper;

    /**
     * 查询企业微信应用
     *
     * @param id 企业微信应用ID
     * @return 企业微信应用
     */
    @Override
    public QywxApp selectQywxAppById(Long id)
    {
        return qywxAppMapper.selectQywxAppById(id);
    }

    /**
     * 查询企业微信应用列表
     *
     * @param qywxApp 企业微信应用
     * @return 企业微信应用
     */
    @Override
    public List<QywxApp> selectQywxAppList(QywxApp qywxApp)
    {
        return qywxAppMapper.selectQywxAppList(qywxApp);
    }

    /**
     * 新增企业微信应用
     *
     * @param qywxApp 企业微信应用
     * @return 结果
     */
    @Override
    public int insertQywxApp(QywxApp qywxApp)
    {
        qywxApp.setCreateTime(DateUtils.getNowDate());
        return qywxAppMapper.insertQywxApp(qywxApp);
    }

    /**
     * 修改企业微信应用
     *
     * @param qywxApp 企业微信应用
     * @return 结果
     */
    @Override
    public int updateQywxApp(QywxApp qywxApp)
    {
        qywxApp.setUpdateTime(DateUtils.getNowDate());
        return qywxAppMapper.updateQywxApp(qywxApp);
    }

    /**
     * 批量删除企业微信应用
     *
     * @param ids 需要删除的企业微信应用ID
     * @return 结果
     */
    @Override
    public int deleteQywxAppByIds(Long[] ids)
    {
        return qywxAppMapper.deleteQywxAppByIds(ids);
    }

    /**
     * 删除企业微信应用信息
     *
     * @param id 企业微信应用ID
     * @return 结果
     */
    @Override
    public int deleteQywxAppById(Long id)
    {
        return qywxAppMapper.deleteQywxAppById(id);
    }

    @Override
    public void updateSuite(String suiteTicket, String suiteAccessToken, String suiteId) {
        qywxAppMapper.updateSuite(suiteTicket,suiteAccessToken,suiteId);
    }
}
