package com.fs.store.domain;

import lombok.Data;
import java.io.Serializable;

/**
 * 配置信息DTO
 *
 * <p>
 *  此类用于封装配置信息。
 *  包含类型、appKey、appSecret、私钥、公钥、UUID 以及 appid 等配置项。
 * </p>
 *
 * @author xdd
 * @since 2025-02-27
 */
@Data
public class TzConfigInfoDTO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 类型
     * <p>
     * 示例值: "tzbk"
     * </p>
     */
    private String type;

    /**
     * 应用 Key
     * <p>
     * 示例值: "1ef7bb04-a987-45c8-bfa9-1276188b085a"
     * </p>
     */
    private String appKey;

    /**
     * 应用 Secret
     * <p>
     * 示例值: "141B81F09FB32DA2F490BEEBA2135316"
     * </p>
     */
    private String appSecret;

    /**
     * 私钥
     * <p>
     * 示例值: "2AA510FB7AB3637F5044472785A9D1D6EEAEDA1A73EF242570A25C3F23C513AD"
     * </p>
     */
    private String privateKey;

    /**
     * 公钥
     * <p>
     * 示例值: "0452469B7E7BBB00A06A59398967A7A2BA0C727317DC42FF72D146F8069131828DACC6587669FBBDA6637787E23E046C71139E17A16BD489569DA10C9126E3C6BB"
     * </p>
     */
    private String publicKey;

    /**
     * UUID
     * <p>
     * 示例值: "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCB"
     * </p>
     */
    private String uuid;

    /**
     * 应用 ID
     * <p>
     * 示例值: "wx19c8813ffc33d1cb"
     * </p>
     */
    private String appid;

    /**
     * 平台商户号
     */
    private String platMerCstNo;

    /**
     * 交易商户号
     */
    private String tradeMerCstNo;

    /**
     * 业务平台客户号
     */
    private String businessCstNo;

    /**
     * 支付回调url
     */
    private String payNotifyUrl;

    /**
     * 退款回调url
     */
    private String refundNotifyUrl;
}
