package com.fs.store.mapper;

import com.fs.store.domain.FsCouponSchedule;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 定时发放优惠券队列Mapper接口
 *
 * @author fs
 * @date 2025-03-08
 */
@Mapper
public interface FsCouponScheduleMapper
{
    /**
     * 查询定时发放优惠券队列
     *
     * @param id 定时发放优惠券队列ID
     * @return 定时发放优惠券队列
     */
    public FsCouponSchedule selectFsCouponScheduleById(Long id);

    /**
     * 查询定时发放优惠券队列列表
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 定时发放优惠券队列集合
     */
    public List<FsCouponSchedule> selectFsCouponScheduleList(FsCouponSchedule fsCouponSchedule);

    /**
     * 新增定时发放优惠券队列
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 结果
     */
    public int insertFsCouponSchedule(FsCouponSchedule fsCouponSchedule);

    /**
     * 修改定时发放优惠券队列
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 结果
     */
    public int updateFsCouponSchedule(FsCouponSchedule fsCouponSchedule);
    /**
     * 批量修改定时发放优惠券队列
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 结果
     */
    public int updateBatchFsCouponSchedule(@Param("list") List<FsCouponSchedule> fsCouponSchedule);
    /**
     * 删除定时发放优惠券队列
     *
     * @param id 定时发放优惠券队列ID
     * @return 结果
     */
    public int deleteFsCouponScheduleById(Long id);

    /**
     * 批量删除定时发放优惠券队列
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteFsCouponScheduleByIds(Long[] ids);

    /**
     * 查询待发送优惠券
     */
    List<FsCouponSchedule> selectPendingCouponList();

    /**
     * 查询待发送优惠券通过订单id
     * @param orderId
     * @return
     */
    FsCouponSchedule selectFsCouponScheduleByOrderId(@Param("orderId") String orderId);
}
