package com.fs.store.service;

import java.util.List;
import com.fs.store.domain.FsArticleViews;
import com.fs.store.param.FsArticleViewListParam;
import com.fs.store.param.FsArticleViewListQueryParam;
import com.fs.store.vo.FsArticleViewListQueryVO;
import com.fs.store.vo.FsArticleViewListVO;

/**
 * 文章阅读Service接口
 *
 * @author fs
 * @date 2022-03-25
 */
public interface IFsArticleViewsService
{
    /**
     * 查询文章阅读
     *
     * @param viewId 文章阅读ID
     * @return 文章阅读
     */
    public FsArticleViews selectFsArticleViewsById(Long viewId);

    /**
     * 查询文章阅读列表
     *
     * @param fsArticleViews 文章阅读
     * @return 文章阅读集合
     */
    public List<FsArticleViews> selectFsArticleViewsList(FsArticleViews fsArticleViews);

    /**
     * 新增文章阅读
     *
     * @param fsArticleViews 文章阅读
     * @return 结果
     */
    public int insertFsArticleViews(FsArticleViews fsArticleViews);

    /**
     * 修改文章阅读
     *
     * @param fsArticleViews 文章阅读
     * @return 结果
     */
    public int updateFsArticleViews(FsArticleViews fsArticleViews);

    /**
     * 批量删除文章阅读
     *
     * @param viewIds 需要删除的文章阅读ID
     * @return 结果
     */
    public int deleteFsArticleViewsByIds(Long[] viewIds);

    /**
     * 删除文章阅读信息
     *
     * @param viewId 文章阅读ID
     * @return 结果
     */
    public int deleteFsArticleViewsById(Long viewId);


    List<FsArticleViewListQueryVO> selectFsArticleViewsTopByArticleId(Integer articleId);

    int updateView(Long articleId, long userId);

    List<FsArticleViewListQueryVO> selectFsArticleViewsListQueryVO(FsArticleViewListQueryParam param);

    List<FsArticleViewListVO> selectFsArticleViewsListVO(FsArticleViewListParam param);
}
