package com.fs.store.service;


import com.fs.store.domain.FsCouponSchedule;

import java.util.List;

/**
 * 定时发放优惠券队列Service接口
 *
 * @author fs
 * @date 2025-03-08
 */
public interface IFsCouponScheduleService
{
    /**
     * 查询定时发放优惠券队列
     *
     * @param id 定时发放优惠券队列ID
     * @return 定时发放优惠券队列
     */
    public FsCouponSchedule selectFsCouponScheduleById(Long id);

    /**
     * 查询定时发放优惠券队列通过订单id
     * @param orderId 订单id
     * @return FsCouponSchedule
     */
    FsCouponSchedule selectFsCouponScheduleByOrderId(String orderId);

    /**
     * 退款将定时发放优惠券的状态设置为已退款
     * @param orderCode 订单号码
     */
    void setScheduleCouponRefund(String orderCode);
    /**
     * 查询定时发放优惠券队列列表
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 定时发放优惠券队列集合
     */
    public List<FsCouponSchedule> selectFsCouponScheduleList(FsCouponSchedule fsCouponSchedule);

    /**
     * 新增定时发放优惠券队列
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 结果
     */
    public int insertFsCouponSchedule(FsCouponSchedule fsCouponSchedule);

    /**
     * 修改定时发放优惠券队列
     *
     * @param fsCouponSchedule 定时发放优惠券队列
     * @return 结果
     */
    public int updateFsCouponSchedule(FsCouponSchedule fsCouponSchedule);

    /**
     * 批量删除定时发放优惠券队列
     *
     * @param ids 需要删除的定时发放优惠券队列ID
     * @return 结果
     */
    public int deleteFsCouponScheduleByIds(Long[] ids);

    /**
     * 删除定时发放优惠券队列信息
     *
     * @param id 定时发放优惠券队列ID
     * @return 结果
     */
    public int deleteFsCouponScheduleById(Long id);

    /**
     * 发放优惠券
     */
    void issueCoupon();


}
