package com.fs.store.service;

import com.fs.store.domain.FsDoctorArticle;
import com.fs.store.param.FsDoctorArticleListUParam;
import com.fs.store.vo.FsDoctorArticleListUVO;
import com.fs.store.vo.FsDoctorArticleListVO;
import com.fs.store.vo.FsDoctorArticleUVO;
import com.fs.store.vo.FsDoctorArticleVO;

import java.util.List;

/**
 * 医生文章Service接口
 *
 * @author fs
 * @date 2023-06-05
 */
public interface IFsDoctorArticleService
{
    /**
     * 查询医生文章
     *
     * @param articleId 医生文章主键
     * @return 医生文章
     */
    public FsDoctorArticleVO selectFsDoctorArticleByArticleId(Long articleId);

    /**
     * 查询医生文章列表
     *
     * @param fsDoctorArticle 医生文章
     * @return 医生文章集合
     */
    public List<FsDoctorArticle> selectFsDoctorArticleList(FsDoctorArticle fsDoctorArticle);

    /**
     * 新增医生文章
     *
     * @param fsDoctorArticle 医生文章
     * @return 结果
     */
    public int insertFsDoctorArticle(FsDoctorArticle fsDoctorArticle);

    /**
     * 修改医生文章
     *
     * @param fsDoctorArticle 医生文章
     * @return 结果
     */
    public int updateFsDoctorArticle(FsDoctorArticle fsDoctorArticle);

    /**
     * 批量删除医生文章
     *
     * @param articleIds 需要删除的医生文章主键集合
     * @return 结果
     */
    public int deleteFsDoctorArticleByArticleIds(Long[] articleIds);

    /**
     * 删除医生文章信息
     *
     * @param articleId 医生文章主键
     * @return 结果
     */
    public int deleteFsDoctorArticleByArticleId(Long articleId);

    List<FsDoctorArticleListVO> selectFsDoctorArticleListVO(FsDoctorArticle fsDoctorArticle);

    List<FsDoctorArticleListUVO> selectFsDoctorArticleListUVO(FsDoctorArticleListUParam param);

    int updateViews(Long articleId);

    FsDoctorArticleUVO selectFsDoctorArticleUVOByArticleId(Long articleId);


}
