package com.fs.store.service;

import java.util.List;
import com.fs.store.domain.FsShippingTemplatesFree;
import com.fs.store.dto.TemplateDTO;
import com.fs.store.strategy.FreeShippingRule;

/**
 * 免邮费Service接口
 *
 * @author fs
 * @date 2022-03-15
 */
public interface IFsShippingTemplatesFreeService
{
    /**
     * 查询免邮费
     *
     * @param id 免邮费ID
     * @return 免邮费
     */
    public FsShippingTemplatesFree selectFsShippingTemplatesFreeById(Long id);

    /**
     * 查询免邮费列表
     *
     * @param fsShippingTemplatesFree 免邮费
     * @return 免邮费集合
     */
    public List<FsShippingTemplatesFree> selectFsShippingTemplatesFreeList(FsShippingTemplatesFree fsShippingTemplatesFree);

    /**
     * 新增免邮费
     *
     * @param fsShippingTemplatesFree 免邮费
     * @return 结果
     */
    public int insertFsShippingTemplatesFree(FsShippingTemplatesFree fsShippingTemplatesFree);

    /**
     * 修改免邮费
     *
     * @param fsShippingTemplatesFree 免邮费
     * @return 结果
     */
    public int updateFsShippingTemplatesFree(FsShippingTemplatesFree fsShippingTemplatesFree);

    /**
     * 批量删除免邮费
     *
     * @param ids 需要删除的免邮费ID
     * @return 结果
     */
    public int deleteFsShippingTemplatesFreeByIds(Long[] ids);

    /**
     * 删除免邮费信息
     *
     * @param id 免邮费ID
     * @return 结果
     */
    public int deleteFsShippingTemplatesFreeById(Long id);

    int selectCountByTemplateDTO(TemplateDTO mapValue);

    /**
     * 查询免邮费规则
     * @param templateId 模板id
     * @return List<FreeShippingRule>
     */
    List<FsShippingTemplatesFree> selectFreeShippingRuleByTempId(Long templateId);
}
