package com.fs.store.service;

import java.util.List;

import com.fs.store.domain.FsUser;
import com.fs.store.domain.FsUserSign;
import com.fs.store.param.FsUserSignQueryParam;

/**
 * 签到记录Service接口
 * 
 * @author fs
 * @date 2022-03-15
 */
public interface IFsUserSignService 
{
    /**
     * 查询签到记录
     * 
     * @param int 签到记录ID
     * @return 签到记录
     */
    public FsUserSign selectFsUserSignById(Long id);

    /**
     * 查询签到记录列表
     * 
     * @param fsUserSign 签到记录
     * @return 签到记录集合
     */
    public List<FsUserSign> selectFsUserSignList(FsUserSign fsUserSign);

    /**
     * 新增签到记录
     * 
     * @param fsUserSign 签到记录
     * @return 结果
     */
    public int insertFsUserSign(FsUserSign fsUserSign);

    /**
     * 修改签到记录
     * 
     * @param fsUserSign 签到记录
     * @return 结果
     */
    public int updateFsUserSign(FsUserSign fsUserSign);

    /**
     * 批量删除签到记录
     * 
     * @param ints 需要删除的签到记录ID
     * @return 结果
     */
    public int deleteFsUserSignByIds(Long[] ids);

    /**
     * 删除签到记录信息
     * 
     * @param int 签到记录ID
     * @return 结果
     */
    public int deleteFsUserSignById(Long id);

    Long sign(FsUser user);

    List<FsUserSign> selectFsUserSignListQuery(FsUserSignQueryParam param);

    Long getSign(FsUser user);

    Boolean isDaySign(FsUser user);
}
