package com.fs.store.service.impl;

import com.fs.common.exception.CustomException;
import com.fs.common.utils.DateUtils;
import com.fs.store.domain.FsChineseMedicine;
import com.fs.store.mapper.FsChineseMedicineMapper;
import com.fs.store.param.FsChineseMedicineListUParam;
import com.fs.store.service.IFsChineseMedicineService;
import com.fs.store.vo.FsChineseMedicineListUVO;
import com.fs.store.vo.FsChineseMedicineListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 中药科普管理Service业务层处理
 *
 * @author fs
 * @date 2023-10-23
 */
@Service
public class FsChineseMedicineServiceImpl implements IFsChineseMedicineService
{
    @Autowired
    private FsChineseMedicineMapper fsChineseMedicineMapper;

    /**
     * 查询中药科普管理
     *
     * @param id 中药科普管理主键
     * @return 中药科普管理
     */
    @Override
    public FsChineseMedicine selectFsChineseMedicineById(Long id)
    {
        return fsChineseMedicineMapper.selectFsChineseMedicineById(id);
    }

    /**
     * 查询中药科普管理列表
     *
     * @param fsChineseMedicine 中药科普管理
     * @return 中药科普管理
     */
    @Override
    public List<FsChineseMedicine> selectFsChineseMedicineList(FsChineseMedicine fsChineseMedicine)
    {
        return fsChineseMedicineMapper.selectFsChineseMedicineList(fsChineseMedicine);
    }

    /**
     * 新增中药科普管理
     *
     * @param fsChineseMedicine 中药科普管理
     * @return 结果
     */
    @Override
    public int insertFsChineseMedicine(FsChineseMedicine fsChineseMedicine)
    {
        return fsChineseMedicineMapper.insertFsChineseMedicine(fsChineseMedicine);
    }

    /**
     * 修改中药科普管理
     *
     * @param fsChineseMedicine 中药科普管理
     * @return 结果
     */
    @Override
    public int updateFsChineseMedicine(FsChineseMedicine fsChineseMedicine)
    {
        return fsChineseMedicineMapper.updateFsChineseMedicine(fsChineseMedicine);
    }

    /**
     * 批量删除中药科普管理
     *
     * @param ids 需要删除的中药科普管理主键
     * @return 结果
     */
    @Override
    public int deleteFsChineseMedicineByIds(Long[] ids)
    {
        return fsChineseMedicineMapper.deleteFsChineseMedicineByIds(ids);
    }

    /**
     * 删除中药科普管理信息
     *
     * @param id 中药科普管理主键
     * @return 结果
     */
    @Override
    public int deleteFsChineseMedicineById(Long id)
    {
        return fsChineseMedicineMapper.deleteFsChineseMedicineById(id);
    }

    @Override
    public List<FsChineseMedicineListVO> selectFsChineseMedicineListVO(FsChineseMedicine fsChineseMedicine) {
        return fsChineseMedicineMapper.selectFsChineseMedicineListVO(fsChineseMedicine);
    }

    @Override
    public String importData(List<FsChineseMedicine> list) {
        if (com.fs.common.utils.StringUtils.isNull(list) || list.size() == 0)
        {
            throw new CustomException("导入数据不能为空！");
        }
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (FsChineseMedicine vo : list)
        {
            try
            {
                vo.setCreateTime(DateUtils.getNowDate());
                int i = fsChineseMedicineMapper.insertFsChineseMedicine(vo);

                successNum++;
                successMsg.append("<br/>" + successNum + "、名称 " + vo.getMedicineName() + " 导入成功");

            }
            catch (Exception e)
            {

                failureNum++;
                String msg = "<br/>" + failureNum + "、名称 " +vo.getMedicineName() + " 导入失败：";
                failureMsg.append(msg + e.getMessage());
            }
        }
        if (failureNum > 0)
        {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确，错误如下：");
            throw new CustomException(failureMsg.toString());
        }
        else
        {
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
        }
        return successMsg.toString();
    }

    @Override
    public List<FsChineseMedicineListUVO> selectFsChineseMedicineListUVO(FsChineseMedicineListUParam param) {
        return fsChineseMedicineMapper.selectFsChineseMedicineListUVO(param);
    }
}
