package com.fs.store.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsPrescribeDrugMapper;
import com.fs.store.domain.FsPrescribeDrug;
import com.fs.store.service.IFsPrescribeDrugService;

/**
 * 处方药品Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsPrescribeDrugServiceImpl implements IFsPrescribeDrugService 
{
    @Autowired
    private FsPrescribeDrugMapper fsPrescribeDrugMapper;

    /**
     * 查询处方药品
     * 
     * @param drugId 处方药品ID
     * @return 处方药品
     */
    @Override
    public FsPrescribeDrug selectFsPrescribeDrugById(Long drugId)
    {
        return fsPrescribeDrugMapper.selectFsPrescribeDrugById(drugId);
    }

    /**
     * 查询处方药品列表
     * 
     * @param fsPrescribeDrug 处方药品
     * @return 处方药品
     */
    @Override
    public List<FsPrescribeDrug> selectFsPrescribeDrugList(FsPrescribeDrug fsPrescribeDrug)
    {
        return fsPrescribeDrugMapper.selectFsPrescribeDrugList(fsPrescribeDrug);
    }

    /**
     * 新增处方药品
     * 
     * @param fsPrescribeDrug 处方药品
     * @return 结果
     */
    @Override
    public int insertFsPrescribeDrug(FsPrescribeDrug fsPrescribeDrug)
    {
        return fsPrescribeDrugMapper.insertFsPrescribeDrug(fsPrescribeDrug);
    }

    /**
     * 修改处方药品
     * 
     * @param fsPrescribeDrug 处方药品
     * @return 结果
     */
    @Override
    public int updateFsPrescribeDrug(FsPrescribeDrug fsPrescribeDrug)
    {
        return fsPrescribeDrugMapper.updateFsPrescribeDrug(fsPrescribeDrug);
    }

    /**
     * 批量删除处方药品
     * 
     * @param drugIds 需要删除的处方药品ID
     * @return 结果
     */
    @Override
    public int deleteFsPrescribeDrugByIds(Long[] drugIds)
    {
        return fsPrescribeDrugMapper.deleteFsPrescribeDrugByIds(drugIds);
    }

    /**
     * 删除处方药品信息
     * 
     * @param drugId 处方药品ID
     * @return 结果
     */
    @Override
    public int deleteFsPrescribeDrugById(Long drugId)
    {
        return fsPrescribeDrugMapper.deleteFsPrescribeDrugById(drugId);
    }
}
