package com.fs.store.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsStoreCouponIssueUserMapper;
import com.fs.store.domain.FsStoreCouponIssueUser;
import com.fs.store.service.IFsStoreCouponIssueUserService;

/**
 * 优惠券用户领取记录Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreCouponIssueUserServiceImpl implements IFsStoreCouponIssueUserService 
{
    @Autowired
    private FsStoreCouponIssueUserMapper fsStoreCouponIssueUserMapper;

    /**
     * 查询优惠券用户领取记录
     * 
     * @param id 优惠券用户领取记录ID
     * @return 优惠券用户领取记录
     */
    @Override
    public FsStoreCouponIssueUser selectFsStoreCouponIssueUserById(Long id)
    {
        return fsStoreCouponIssueUserMapper.selectFsStoreCouponIssueUserById(id);
    }

    /**
     * 查询优惠券用户领取记录列表
     * 
     * @param fsStoreCouponIssueUser 优惠券用户领取记录
     * @return 优惠券用户领取记录
     */
    @Override
    public List<FsStoreCouponIssueUser> selectFsStoreCouponIssueUserList(FsStoreCouponIssueUser fsStoreCouponIssueUser)
    {
        return fsStoreCouponIssueUserMapper.selectFsStoreCouponIssueUserList(fsStoreCouponIssueUser);
    }

    /**
     * 新增优惠券用户领取记录
     * 
     * @param fsStoreCouponIssueUser 优惠券用户领取记录
     * @return 结果
     */
    @Override
    public int insertFsStoreCouponIssueUser(FsStoreCouponIssueUser fsStoreCouponIssueUser)
    {
        fsStoreCouponIssueUser.setCreateTime(DateUtils.getNowDate());
        return fsStoreCouponIssueUserMapper.insertFsStoreCouponIssueUser(fsStoreCouponIssueUser);
    }

    /**
     * 修改优惠券用户领取记录
     * 
     * @param fsStoreCouponIssueUser 优惠券用户领取记录
     * @return 结果
     */
    @Override
    public int updateFsStoreCouponIssueUser(FsStoreCouponIssueUser fsStoreCouponIssueUser)
    {
        fsStoreCouponIssueUser.setUpdateTime(DateUtils.getNowDate());
        return fsStoreCouponIssueUserMapper.updateFsStoreCouponIssueUser(fsStoreCouponIssueUser);
    }

    /**
     * 批量删除优惠券用户领取记录
     * 
     * @param ids 需要删除的优惠券用户领取记录ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreCouponIssueUserByIds(Long[] ids)
    {
        return fsStoreCouponIssueUserMapper.deleteFsStoreCouponIssueUserByIds(ids);
    }

    /**
     * 删除优惠券用户领取记录信息
     * 
     * @param id 优惠券用户领取记录ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreCouponIssueUserById(Long id)
    {
        return fsStoreCouponIssueUserMapper.deleteFsStoreCouponIssueUserById(id);
    }
}
