package com.fs.store.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsStoreOrderStatusMapper;
import com.fs.store.domain.FsStoreOrderStatus;
import com.fs.store.service.IFsStoreOrderStatusService;

/**
 * 订单操作记录Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreOrderStatusServiceImpl implements IFsStoreOrderStatusService 
{
    @Autowired
    private FsStoreOrderStatusMapper fsStoreOrderStatusMapper;

    /**
     * 查询订单操作记录
     * 
     * @param id 订单操作记录ID
     * @return 订单操作记录
     */
    @Override
    public FsStoreOrderStatus selectFsStoreOrderStatusById(Long id)
    {
        return fsStoreOrderStatusMapper.selectFsStoreOrderStatusById(id);
    }

    /**
     * 查询订单操作记录列表
     * 
     * @param fsStoreOrderStatus 订单操作记录
     * @return 订单操作记录
     */
    @Override
    public List<FsStoreOrderStatus> selectFsStoreOrderStatusList(FsStoreOrderStatus fsStoreOrderStatus)
    {
        return fsStoreOrderStatusMapper.selectFsStoreOrderStatusList(fsStoreOrderStatus);
    }

    /**
     * 新增订单操作记录
     * 
     * @param fsStoreOrderStatus 订单操作记录
     * @return 结果
     */
    @Override
    public int insertFsStoreOrderStatus(FsStoreOrderStatus fsStoreOrderStatus)
    {
        return fsStoreOrderStatusMapper.insertFsStoreOrderStatus(fsStoreOrderStatus);
    }

    /**
     * 修改订单操作记录
     * 
     * @param fsStoreOrderStatus 订单操作记录
     * @return 结果
     */
    @Override
    public int updateFsStoreOrderStatus(FsStoreOrderStatus fsStoreOrderStatus)
    {
        return fsStoreOrderStatusMapper.updateFsStoreOrderStatus(fsStoreOrderStatus);
    }

    /**
     * 批量删除订单操作记录
     * 
     * @param ids 需要删除的订单操作记录ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderStatusByIds(Long[] ids)
    {
        return fsStoreOrderStatusMapper.deleteFsStoreOrderStatusByIds(ids);
    }

    /**
     * 删除订单操作记录信息
     * 
     * @param id 订单操作记录ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreOrderStatusById(Long id)
    {
        return fsStoreOrderStatusMapper.deleteFsStoreOrderStatusById(id);
    }

    @Override
    public int create(Long id, String changetype, String desc) {
        FsStoreOrderStatus storeOrderStatus = new FsStoreOrderStatus();
        storeOrderStatus.setOrderId(id);
        storeOrderStatus.setChangeType(changetype);
        storeOrderStatus.setChangeMessage(desc);
        return fsStoreOrderStatusMapper.insertFsStoreOrderStatus(storeOrderStatus);
    }
}
