package com.fs.store.service.impl;

import java.util.List;

import com.fs.store.param.FsProductAttrValueParam;
import com.fs.store.param.FsStoreProductAttrValueQueryParam;
import com.fs.store.param.FsStoreTuiProductAttrValueParam;
import com.fs.store.vo.FsStoreProductAttrValueQueryVO;
import com.fs.store.vo.FsStoreProductAttrValueVO;
import com.fs.store.vo.FsStoreTuiProductAttrValueVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsStoreProductAttrValueMapper;
import com.fs.store.domain.FsStoreProductAttrValue;
import com.fs.store.service.IFsStoreProductAttrValueService;

/**
 * 商品属性值Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreProductAttrValueServiceImpl implements IFsStoreProductAttrValueService 
{
    @Autowired
    private FsStoreProductAttrValueMapper fsStoreProductAttrValueMapper;

    /**
     * 查询商品属性值
     * 
     * @param id 商品属性值ID
     * @return 商品属性值
     */
    @Override
    public FsStoreProductAttrValue selectFsStoreProductAttrValueById(Long id)
    {
        return fsStoreProductAttrValueMapper.selectFsStoreProductAttrValueById(id);
    }

    /**
     * 查询商品属性值列表
     * 
     * @param fsStoreProductAttrValue 商品属性值
     * @return 商品属性值
     */
    @Override
    public List<FsStoreProductAttrValue> selectFsStoreProductAttrValueList(FsStoreProductAttrValue fsStoreProductAttrValue)
    {
        return fsStoreProductAttrValueMapper.selectFsStoreProductAttrValueList(fsStoreProductAttrValue);
    }

    /**
     * 新增商品属性值
     * 
     * @param fsStoreProductAttrValue 商品属性值
     * @return 结果
     */
    @Override
    public int insertFsStoreProductAttrValue(FsStoreProductAttrValue fsStoreProductAttrValue)
    {
        return fsStoreProductAttrValueMapper.insertFsStoreProductAttrValue(fsStoreProductAttrValue);
    }

    /**
     * 修改商品属性值
     * 
     * @param fsStoreProductAttrValue 商品属性值
     * @return 结果
     */
    @Override
    public int updateFsStoreProductAttrValue(FsStoreProductAttrValue fsStoreProductAttrValue)
    {
        return fsStoreProductAttrValueMapper.updateFsStoreProductAttrValue(fsStoreProductAttrValue);
    }

    /**
     * 批量删除商品属性值
     * 
     * @param ids 需要删除的商品属性值ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreProductAttrValueByIds(Long[] ids)
    {
        return fsStoreProductAttrValueMapper.deleteFsStoreProductAttrValueByIds(ids);
    }

    /**
     * 删除商品属性值信息
     * 
     * @param id 商品属性值ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreProductAttrValueById(Long id)
    {
        return fsStoreProductAttrValueMapper.deleteFsStoreProductAttrValueById(id);
    }

    @Override
    public List<FsStoreProductAttrValue> selectFsStoreProductAttrValueByProductId(Long productId) {
        return fsStoreProductAttrValueMapper.selectFsStoreProductAttrValueByProductId(productId);
    }

    @Override
    public int incProductAttrStock(Long num, Long productId, Long productAttrValueId) {
        return fsStoreProductAttrValueMapper.incProductAttrStock(num,productId,productAttrValueId);
    }

    @Override
    public List<FsStoreProductAttrValueVO> selectFsStoreProductAttrValueListVO(FsProductAttrValueParam param) {
        return fsStoreProductAttrValueMapper.selectFsStoreProductAttrValueListVO(param);
    }

    @Override
    public List<FsStoreProductAttrValueQueryVO> selectStoreProductAttrValueListQuery(FsStoreProductAttrValueQueryParam param) {
        return fsStoreProductAttrValueMapper.selectStoreProductAttrValueListQuery(param);
    }

    @Override
    public List<FsStoreTuiProductAttrValueVO> selectStoreTuiProductAttrValueVOList(FsStoreTuiProductAttrValueParam param) {
        return fsStoreProductAttrValueMapper.selectStoreTuiProductAttrValueVOList(param);
    }


}
