package com.fs.store.service.impl;

import com.fs.common.utils.DateUtils;
import com.fs.store.domain.FsTestTempItem;
import com.fs.store.mapper.FsTestTempItemMapper;
import com.fs.store.param.FsTestTempItemListUParam;
import com.fs.store.param.FsTestTempItemParam;
import com.fs.store.service.IFsTestTempItemService;
import com.fs.store.vo.FsTestTempItemListUVO;
import com.fs.store.vo.FsTestTempItemListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 模板项目Service业务层处理
 *
 * @author fs
 * @date 2023-09-04
 */
@Service
public class FsTestTempItemServiceImpl implements IFsTestTempItemService
{
    @Autowired
    private FsTestTempItemMapper fsTestTempItemMapper;

    /**
     * 查询模板项目
     *
     * @param itemId 模板项目主键
     * @return 模板项目
     */
    @Override
    public FsTestTempItem selectFsTestTempItemByItemId(Long itemId)
    {
        return fsTestTempItemMapper.selectFsTestTempItemByItemId(itemId);
    }

    /**
     * 查询模板项目列表
     *
     * @param fsTestTempItem 模板项目
     * @return 模板项目
     */
    @Override
    public List<FsTestTempItem> selectFsTestTempItemList(FsTestTempItem fsTestTempItem)
    {
        return fsTestTempItemMapper.selectFsTestTempItemList(fsTestTempItem);
    }

    /**
     * 新增模板项目
     *
     * @param fsTestTempItem 模板项目
     * @return 结果
     */
    @Override
    public int insertFsTestTempItem(FsTestTempItem fsTestTempItem)
    {
        fsTestTempItem.setCreateTime(DateUtils.getNowDate());
        return fsTestTempItemMapper.insertFsTestTempItem(fsTestTempItem);
    }

    /**
     * 修改模板项目
     *
     * @param fsTestTempItem 模板项目
     * @return 结果
     */
    @Override
    public int updateFsTestTempItem(FsTestTempItem fsTestTempItem)
    {
        fsTestTempItem.setUpdateTime(DateUtils.getNowDate());
        return fsTestTempItemMapper.updateFsTestTempItem(fsTestTempItem);
    }

    /**
     * 批量删除模板项目
     *
     * @param itemIds 需要删除的模板项目主键
     * @return 结果
     */
    @Override
    public int deleteFsTestTempItemByItemIds(Long[] itemIds)
    {
        return fsTestTempItemMapper.deleteFsTestTempItemByItemIds(itemIds);
    }

    /**
     * 删除模板项目信息
     *
     * @param itemId 模板项目主键
     * @return 结果
     */
    @Override
    public int deleteFsTestTempItemByItemId(Long itemId)
    {
        return fsTestTempItemMapper.deleteFsTestTempItemByItemId(itemId);
    }

    @Override
    public List<FsTestTempItemListVO> selectFsTestTempItemListVO(FsTestTempItemParam fsTestTempItem) {
        return fsTestTempItemMapper.selectFsTestTempItemListVO(fsTestTempItem);
    }

    @Override
    public List<FsTestTempItemListUVO> selectFsTestTempItemListUVO(FsTestTempItemListUParam param) {
        return fsTestTempItemMapper.selectFsTestTempItemListUVO(param);
    }
}
