package com.fs.store.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsWechatTemplateMapper;
import com.fs.store.domain.FsWechatTemplate;
import com.fs.store.service.IFsWechatTemplateService;

/**
 * 微信模板Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsWechatTemplateServiceImpl implements IFsWechatTemplateService 
{
    @Autowired
    private FsWechatTemplateMapper fsWechatTemplateMapper;

    /**
     * 查询微信模板
     * 
     * @param id 微信模板ID
     * @return 微信模板
     */
    @Override
    public FsWechatTemplate selectFsWechatTemplateById(Integer id)
    {
        return fsWechatTemplateMapper.selectFsWechatTemplateById(id);
    }

    /**
     * 查询微信模板列表
     * 
     * @param fsWechatTemplate 微信模板
     * @return 微信模板
     */
    @Override
    public List<FsWechatTemplate> selectFsWechatTemplateList(FsWechatTemplate fsWechatTemplate)
    {
        return fsWechatTemplateMapper.selectFsWechatTemplateList(fsWechatTemplate);
    }

    /**
     * 新增微信模板
     * 
     * @param fsWechatTemplate 微信模板
     * @return 结果
     */
    @Override
    public int insertFsWechatTemplate(FsWechatTemplate fsWechatTemplate)
    {
        fsWechatTemplate.setCreateTime(DateUtils.getNowDate());
        return fsWechatTemplateMapper.insertFsWechatTemplate(fsWechatTemplate);
    }

    /**
     * 修改微信模板
     * 
     * @param fsWechatTemplate 微信模板
     * @return 结果
     */
    @Override
    public int updateFsWechatTemplate(FsWechatTemplate fsWechatTemplate)
    {
        fsWechatTemplate.setUpdateTime(DateUtils.getNowDate());
        return fsWechatTemplateMapper.updateFsWechatTemplate(fsWechatTemplate);
    }

    /**
     * 批量删除微信模板
     * 
     * @param ids 需要删除的微信模板ID
     * @return 结果
     */
    @Override
    public int deleteFsWechatTemplateByIds(Integer[] ids)
    {
        return fsWechatTemplateMapper.deleteFsWechatTemplateByIds(ids);
    }

    /**
     * 删除微信模板信息
     * 
     * @param id 微信模板ID
     * @return 结果
     */
    @Override
    public int deleteFsWechatTemplateById(Integer id)
    {
        return fsWechatTemplateMapper.deleteFsWechatTemplateById(id);
    }

    @Override
    public FsWechatTemplate selectFsWechatTemplateByKey(String key) {
        return fsWechatTemplateMapper.selectFsWechatTemplateByKey(key);
    }

    @Override
    public List<String> selectFsWechatTemplateIds() {
        return fsWechatTemplateMapper.selectFsWechatTemplateIds();
    }

    @Override
    public List<String> selectFsWechatTemplateIdsByKeys(String key) {
        return fsWechatTemplateMapper.selectFsWechatTemplateIdsByKeys(key);
    }
}
